@@ -1,8 +1,7 @@
 import asyncio
 import logging
-import traceback
+import sys
 from functools import wraps
-from pathlib import Path
 from typing import List, Tuple, Dict
 from random import gauss
 
@@ -14,8 +13,9 @@ from yarl import URL
 
 from ..base_functions.base_functions import FILE_FORMATS, MAX_FILENAME_LENGTH, log, logger, sanitize, FailureException
 from ..base_functions.sql_helper import SQLHelper
-from ..base_functions.data_classes import AlbumItem, CascadeItem, FileLock
+from ..base_functions.data_classes import AlbumItem, CascadeItem, FileLock, AuthData, SkipData
 from ..client.client import Client, DownloadSession
+from ..scraper.scraper import scrape
 
 
 def retry(f):
@@ -24,16 +24,41 @@ def retry(f):
         while True:
             try:
                 return await f(self, *args, **kwargs)
-            except FailureException:
+            except FailureException as e:
                 if not self.disable_attempt_limit:
-                    if self.current_attempt[str(args[0])] >= self.attempts - 1:
+                    if self.current_attempt[args[0].parts[-1]] >= self.attempts - 1:
                         logger.debug('Skipping %s...', args[0])
                         raise
-                logger.debug(f'Retrying ({self.current_attempt[str(args[0])]}) {args[0]}...')
-                self.current_attempt[str(args[0])] += 1
+                logger.debug(f'Retrying ({self.current_attempt[args[0].parts[-1]]}) {args[0]}...')
+                self.current_attempt[args[0].parts[-1]] += 1
 
-                if 'cyberdrop' in args[0].host:
-                    ext = '.'+args[0].name.split('.')[-1]
+                if e.rescrape:
+                    skip_data = SkipData(self.runtime_args['skip_hosts'])
+                    jdownloader_args = {"jdownloader_enable": None, "jdownloader_username": None,
+                                        "jdownloader_password": None, "jdownloader_device": None}
+                    links = [await self.album_obj.get_referrer(URL(args[0]))]
+                    content_object = await scrape(urls=links, client=self.client, file_args=self.file_args,
+                                                  jdownloader_args=jdownloader_args,
+                                                  runtime_args=self.runtime_args, jdownloader_auth=AuthData("", ""),
+                                                  simpcity_auth=AuthData("", ""),
+                                                  socialmediagirls_auth=AuthData("", ""),
+                                                  xbunker_auth=AuthData("", ""), skip_data=skip_data, quiet=True)
+                    await log("Attempting rescrape for " + str(args[0]), quiet=True)
+                    if not await content_object.is_empty():
+                        link_pairs = []
+                        for domain in content_object.domains.keys():
+                            for album in content_object.domains[domain].albums.keys():
+                                link_pairs = content_object.domains[domain].albums[album].link_pairs
+                        map = await self.album_obj.replace_link_pairs(link_pairs)
+                        replaced_link = map[args[0]]
+                        args = list(args)
+                        args[0] = replaced_link
+                        args = tuple(args)
+                    else:
+                        raise
+
+                elif 'cyberdrop' in args[0].host:
+                    ext = '.' + args[0].name.split('.')[-1]
                     if ext in FILE_FORMATS['Images']:
                         args = list(args)
                         args[0] = args[0].with_host('img-01.cyberdrop.to')
@@ -42,7 +67,9 @@ def retry(f):
                         args = list(args)
                         args[0] = URL(str(args[0]).replace('fs-05.', 'fs-04.'))
                         args = tuple(args)
+
                 await asyncio.sleep(2)
+
     return wrapper
 
 
@@ -70,14 +97,16 @@ class Downloader:
 
         self.proxy = runtime_args['proxy']
 
-    """Changed from aiohttp exceptions caught to FailureException to allow for partial downloads."""
+        self.runtime_args = runtime_args
+        self.file_args = file_args
+
 
     @retry
     async def download_file(self, url: URL, referral: URL, filename: str, session: DownloadSession,
                             show_progress: bool = True) -> None:
         """Download the content of given URL"""
-        if str(url) not in self.current_attempt:
-            self.current_attempt[str(url)] = 0
+        if url.parts[-1] not in self.current_attempt:
+            self.current_attempt[url.parts[-1]] = 0
 
         referer = str(referral)
         db_path = url.path
@@ -87,7 +116,7 @@ class Downloader:
             db_path = db_path.split('/')
             db_path.pop(0)
             db_path.pop(1)
-            db_path = '/'+'/'.join(db_path)
+            db_path = '/' + '/'.join(db_path)
 
         # return if completed already
         if await self.SQL_helper.sql_check_existing(db_path):
@@ -157,18 +186,37 @@ class Downloader:
             await self.rename_file(filename, url, db_path)
             await self.File_Lock.remove_lock(original_filename)
 
-        except (aiohttp.client_exceptions.ClientPayloadError, aiohttp.client_exceptions.ClientOSError,
-                aiohttp.client_exceptions.ServerDisconnectedError, asyncio.TimeoutError,
-                aiohttp.client_exceptions.ClientResponseError, FailureException) as e:
+        except FailureException as e:
             try:
                 await self.File_Lock.remove_lock(original_filename)
             except:
                 pass
 
             logger.debug(e)
+            logger.debug("Error status code: " + str(e.code))
+            logger.debug("Error message: " + str(e.message))
+            if 400 <= e.code < 500 and e.code != 429:
+                logger.debug("We ran into a 400 level error: %s", str(e.code))
+                if 'media-files.bunkr' in url.host:
+                    pass
+                else:
+                    return
+            raise FailureException(code=e.code, message=e.message, rescrape=e.rescrape)
+
+        except (aiohttp.client_exceptions.ClientPayloadError, aiohttp.client_exceptions.ClientOSError,
+                aiohttp.client_exceptions.ServerDisconnectedError, asyncio.TimeoutError,
+                aiohttp.client_exceptions.ClientResponseError) as e:
+            try:
+                await self.File_Lock.remove_lock(original_filename)
+            except:
+                pass
+
+            if hasattr(e, "message"):
+                logging.debug(f"\n{url} ({e.message})")
 
             try:
                 logger.debug("Error status code: " + str(e.code))
+                logger.debug("Error message: " + str(e.message))
                 if 400 <= e.code < 500 and e.code != 429:
                     logger.debug("We ran into a 400 level error: %s", str(e.code))
                     if 'media-files.bunkr' in url.host:
@@ -191,6 +239,7 @@ class Downloader:
             temp_file.rename(complete_file)
 
         await self.SQL_helper.sql_update_file(db_path, filename, 1)
+        self.current_attempt.pop(url.parts[-1])
         logger.debug("Finished " + filename)
 
     async def get_filename(self, url: URL, referral: URL, session: DownloadSession):
@@ -198,6 +247,12 @@ class Downloader:
         referer = str(referral)
 
         filename = url.name
+        if hasattr(url, "query_string"):
+            query_str = url.query_string
+            ext = '.' + query_str.split('.')[-1].lower()
+            if (ext in FILE_FORMATS['Images'] or ext in FILE_FORMATS['Videos'] or
+                    ext in FILE_FORMATS['Audio'] or ext in FILE_FORMATS['Other']):
+                filename = query_str.split("=")[-1]
         filename = await sanitize(filename)
         if "v=" in filename:
             filename = filename.split('v=')[0]
@@ -271,11 +326,15 @@ class Downloader:
                 await self.download_file(url, referral=referral, filename=filename, session=session,
                                          show_progress=show_progress)
         except Exception as e:
+            if hasattr(e, "rescrape"):
+                if not (self.current_attempt[url.parts[-1]] >= self.attempts - 1) and e.rescrape:
+                    return
+            self.current_attempt.pop(url.parts[-1])
             await log(f"\nError attempting {url}")
+            await log(sys.exc_info())
             if hasattr(e, "message"):
                 logging.debug(f"\n{url} ({e.message})")
 
-
     async def download_all(self, album_obj: AlbumItem, session: DownloadSession, show_progress: bool = True) -> None:
         """Download the data from all given links and store them into corresponding files."""
         coros = [self.download_and_store(url_object, session, show_progress)
